@@ -3,7 +3,7 @@
 /*
     This file is part of Magnum.
 
-    Copyright © 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
+    Copyright © 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019
               Vladimír Vondruš <mosra@centrum.cz>
 
     Permission is hereby granted, free of charge, to any person obtaining a
@@ -32,7 +32,7 @@
 #ifdef _MSC_VER
 #include <algorithm> /* For std::min() */
 #endif
-#include <functional>
+#include <Corrade/Containers/Reference.h>
 #include <Corrade/Utility/Assert.h>
 
 #include "Magnum/OpenDdl/Document.h"
@@ -372,8 +372,8 @@ class MAGNUM_OPENDDL_EXPORT Structure {
 
         explicit Structure(const Document& document, const Document::StructureData& data) noexcept: _document{document}, _data{data} {}
 
-        std::reference_wrapper<const Document> _document;
-        std::reference_wrapper<const Document::StructureData> _data;
+        Containers::Reference<const Document> _document;
+        Containers::Reference<const Document::StructureData> _data;
 };
 
 namespace Implementation {
@@ -391,7 +391,7 @@ namespace Implementation {
     _c(Short)
     _c(UnsignedInt)
     _c(Int)
-    #ifndef MAGNUM_TARGET_WEBGL
+    #ifndef CORRADE_TARGET_EMSCRIPTEN
     _c(UnsignedLong)
     _c(Long)
     #endif
